@@ -59,7 +59,7 @@
 #' t3$cols <- c(t1$cols, t2$cols)
 #' t3
 cols <- function(..., .default = col_guess(), .delim = NULL) {
-  col_types <- rlang::list2(...)
+  col_types <- list2(...)
   is_character <- vapply(col_types, is.character, logical(1))
   col_types[is_character] <- lapply(col_types[is_character], col_concise)
 
@@ -79,14 +79,42 @@ cols_only <- function(...) {
 
 # col_spec ----------------------------------------------------------------
 
-col_spec <- function(col_types, default = col_guess(), delim) {
-  stopifnot(is.list(col_types))
-  stopifnot(is.collector(default))
+col_spec <- function(
+  col_types,
+  default = col_guess(),
+  delim,
+  call = caller_env()
+) {
+  if (!is.list(col_types)) {
+    cli::cli_abort(
+      "{.arg col_types} must be a column specification like that created with {.fun cols} or {.fun cols_only}, not {obj_type_friendly(col_types)}.",
+      call = call
+    )
+  }
+
+  hint <- "Column specifications must be created with the {.code col_*()} functions or their abbreviated character names."
+
+  if (!is.collector(default)) {
+    cli::cli_abort(
+      c(
+        hint,
+        "x" = "Bad {.arg .default} specification."
+      ),
+      call = call
+    )
+  }
 
   is_collector <- vapply(col_types, is.collector, logical(1))
   if (any(!is_collector)) {
-    stop("Some `col_types` are not S3 collector objects: ",
-      paste(which(!is_collector), collapse = ", "), call. = FALSE)
+    # the as.character() is favorable for cli pluralization
+    bad_idx <- as.character(which(!is_collector))
+    cli::cli_abort(
+      c(
+        hint,
+        "x" = "Bad specification{?s} at position{?s}: {bad_idx}."
+      ),
+      call = call
+    )
   }
 
   structure(
@@ -111,28 +139,28 @@ is.col_spec <- function(x) inherits(x, "col_spec")
 #' @examples
 #' as.col_spec("cccnnn")
 #' @export
-as.col_spec <- function(x) UseMethod("as.col_spec")
+as.col_spec <- function(x, call = caller_env()) UseMethod("as.col_spec")
 
 #' @export
-as.col_spec.character <- function(x) {
+as.col_spec.character <- function(x, call = caller_env()) {
   if (is_named(x)) {
-    return(as.col_spec(as.list(x)))
+    return(as.col_spec(as.list(x), call = call))
   }
   letters <- strsplit(x, "")[[1]]
-  col_spec(lapply(letters, col_concise), col_guess(), delim = NULL)
+  col_spec(lapply(letters, col_concise), col_guess(), delim = NULL, call = call)
 }
 
 #' @export
-as.col_spec.NULL <- function(x) {
-  col_spec(list(), delim = NULL)
+as.col_spec.NULL <- function(x, call = caller_env()) {
+  col_spec(list(), delim = NULL, call = call)
 }
 
 #' @export
-as.col_spec.list <- function(x) {
+as.col_spec.list <- function(x, call = caller_env()) {
   do.call(cols, x)
 }
 #' @export
-as.col_spec.col_spec <- function(x) {
+as.col_spec.col_spec <- function(x, call = caller_env()) {
   if (!"delim" %in% names(x)) {
     x["delim"] <- list(NULL)
   }
@@ -140,13 +168,23 @@ as.col_spec.col_spec <- function(x) {
 }
 
 #' @export
-as.col_spec.default <- function(x) {
-  stop("`col_types` must be NULL, a list or a string", call. = FALSE)
+as.col_spec.default <- function(x, call = caller_env()) {
+  cli::cli_abort(
+    "{.arg col_types} must be {.code NULL}, a {.fun cols} specification, or a string, not {obj_type_friendly(x)}.",
+    call = call
+  )
 }
 
 # Conditionally exported in zzz.R
+#' @noRd
 # @export
-print.col_spec <- function(x, n = Inf, condense = NULL, colour = crayon::has_color(), ...) {
+print.col_spec <- function(
+  x,
+  n = Inf,
+  condense = NULL,
+  colour = crayon::has_color(),
+  ...
+) {
   cat(format.col_spec(x, n = n, condense = condense, colour = colour, ...))
 
   invisible(x)
@@ -169,9 +207,15 @@ cols_condense <- function(x) {
 }
 
 # Conditionally exported in zzz.R
+#' @noRd
 # @export
-format.col_spec <- function(x, n = Inf, condense = NULL, colour = crayon::has_color(), ...) {
-
+format.col_spec <- function(
+  x,
+  n = Inf,
+  condense = NULL,
+  colour = crayon::has_color(),
+  ...
+) {
   if (n == 0) {
     return("")
   }
@@ -199,12 +243,13 @@ format.col_spec <- function(x, n = Inf, condense = NULL, colour = crayon::has_co
   delim <- x$delim
 
   if (!is.null(delim) && nzchar(delim)) {
-    delim <- paste0('.delim = ', double_quote(delim), '')
+    delim <- paste0('.delim = ', glue::double_quote(delim), '')
   }
 
   cols_args <- c(
     default,
-    vapply(seq_along(cols),
+    vapply(
+      seq_along(cols),
       function(i) {
         col_funs <- sub("^collector_", "col_", class(cols[[i]])[[1]])
         args <- vapply(cols[[i]], deparse2, character(1), sep = "\n    ")
@@ -219,7 +264,11 @@ format.col_spec <- function(x, n = Inf, condense = NULL, colour = crayon::has_co
         named <- col_names != ""
 
         non_syntactic <- !is_syntactic(col_names) & named
-        col_names[non_syntactic] <- paste0("`", gsub("`", "\\\\`", col_names[non_syntactic]), "`")
+        col_names[non_syntactic] <- paste0(
+          "`",
+          gsub("`", "\\\\`", col_names[non_syntactic]),
+          "`"
+        )
 
         out <- paste0(col_names, " = ", col_funs)
         out[!named] <- col_funs[!named]
@@ -244,14 +293,14 @@ format.col_spec <- function(x, n = Inf, condense = NULL, colour = crayon::has_co
 }
 
 colourise_cols <- function(cols, colourise = crayon::has_color()) {
-
   if (!isTRUE(colourise)) {
     return(cols)
   }
 
   fname <- sub("[(].*", "", cols)
   for (i in seq_along(cols)) {
-    cols[[i]] <- switch(fname,
+    cols[[i]] <- switch(
+      fname,
       col_skip = ,
       col_guess = cols[[i]],
 
@@ -262,37 +311,40 @@ colourise_cols <- function(cols, colourise = crayon::has_color()) {
 
       col_double = ,
       col_integer = ,
-      col_number = crayon::green(cols[[i]]),
+      col_big_integer = ,
+      col_number = green(cols[[i]]),
 
       col_date = ,
       col_datetime = ,
-      col_time = crayon::blue(cols[[i]])
-      )
+      col_time = blue(cols[[i]])
+    )
   }
   cols
 }
 
 # This allows str() on a tibble object to print a little nicer.
 # Conditionally exported in zzz.R
+#' @noRd
 # @export
 str.col_spec <- function(object, ..., indent.str = "") {
-
   # Split the formatted column spec into strings
   specs <- strsplit(format(object), "\n")[[1]]
-  cat(sep = "",
+  cat(
+    sep = "",
     "\n",
 
     # Append the current indentation string to the specs
     paste(indent.str, specs, collapse = "\n"),
 
-    "\n")
+    "\n"
+  )
 }
 
 
 #' Examine the column specifications for a data frame
 #'
 #' `spec()` extracts the full column specification from a tibble
-#' created by readr.
+#' created by vroom.
 #'
 #' @family parsers
 #' @param x The data frame object to extract from
@@ -305,28 +357,33 @@ str.col_spec <- function(object, ..., indent.str = "") {
 #'
 #' cols_condense(s)
 spec <- function(x) {
-  stopifnot(inherits(x, "tbl_df"))
+  if (!inherits(x, "tbl_df")) {
+    cli::cli_abort(
+      "{.arg x} must be a tibble created by vroom, not {obj_type_friendly(x)}."
+    )
+  }
   attr(x, "spec")
 }
 
-col_concise <- function(x) {
-  switch(x,
+col_concise <- function(x, call = caller_env()) {
+  switch(
+    x,
     "_" = ,
-    "skip" =,
-    "NULL" =,
+    "skip" = ,
+    "NULL" = ,
     "-" = col_skip(),
     "NA" = ,
     "?" = col_guess(),
-    character =,
+    character = ,
     c = col_character(),
-    factor =,
+    factor = ,
     f = col_factor(),
-    double =,
-    numeric =,
+    double = ,
+    numeric = ,
     d = col_double(),
-    integer =,
+    integer = ,
     i = col_integer(),
-    big_integer =,
+    big_integer = ,
     I = col_big_integer(),
     logical = ,
     l = col_logical(),
@@ -338,27 +395,25 @@ col_concise <- function(x) {
     datetime = ,
     POSIXct = ,
     T = col_datetime(),
-    time =,
+    time = ,
     t = col_time(),
-    stop("Unknown shortcut: ", x, call. = FALSE)
+    cli::cli_abort(
+      "Unknown column type specification: {.val {x}}",
+      call = call
+    )
   )
 }
 
 vroom_enquo <- function(x) {
-  if (rlang::quo_is_call(x, "c") || rlang::quo_is_call(x, "list")) {
-    return(rlang::as_quosures(rlang::get_expr(x)[-1], rlang::get_env(x)))
+  if (quo_is_call(x, "c") || quo_is_call(x, "list")) {
+    return(as_quosures(get_expr(x)[-1], get_env(x)))
   }
   x
 }
 
 vroom_select <- function(x, col_select, id) {
-  spec <- attr(x, "spec")
-
-  # Drop any NULL columns
-  is_null <- vapply(x, is.null, logical(1))
-  x[is_null] <- NULL
   # reorder and rename columns
-  if (inherits(col_select, "quosures") || !rlang::quo_is_null(col_select)) {
+  if (inherits(col_select, "quosures") || !quo_is_null(col_select)) {
     if (inherits(col_select, "quosures")) {
       vars <- tidyselect::vars_select(c(names(spec(x)$cols), id), !!!col_select)
     } else {
@@ -373,11 +428,16 @@ vroom_select <- function(x, col_select, id) {
     x <- x[vars]
     names(x) <- names(vars)
   }
-  attr(x, "spec") <- spec
   x
 }
 
-col_types_standardise <- function(spec, num_cols, col_names, col_select, name_repair) {
+col_types_standardise <- function(
+  spec,
+  num_cols,
+  col_names,
+  col_select,
+  name_repair
+) {
   if (num_cols == 0) {
     if (length(spec$cols) > 0) {
       num_cols <- length(spec$cols)
@@ -404,7 +464,10 @@ col_types_standardise <- function(spec, num_cols, col_names, col_select, name_re
     if (num_cols < length(spec$cols)) {
       spec$cols <- spec$cols[seq_len(num_cols)]
     } else {
-      spec$cols <- c(spec$cols, rep(list(spec$default), num_cols - length(spec$cols)))
+      spec$cols <- c(
+        spec$cols,
+        rep(list(spec$default), num_cols - length(spec$cols))
+      )
     }
     names(spec$cols) <- col_names[seq_along(spec$cols)]
   } else {
@@ -416,8 +479,13 @@ col_types_standardise <- function(spec, num_cols, col_names, col_select, name_re
 
     bad_types <- !(type_names %in% col_names)
     if (any(bad_types)) {
-      rlang::warn(paste0("The following named parsers don't match the column names: ",
-        paste0(type_names[bad_types], collapse = ", ")), class = "vroom_mismatched_column_name")
+      warn(
+        paste0(
+          "The following named parsers don't match the column names: ",
+          paste0(type_names[bad_types], collapse = ", ")
+        ),
+        class = "vroom_mismatched_column_name"
+      )
       spec$cols <- spec$cols[!bad_types]
       type_names <- type_names[!bad_types]
     }
@@ -432,11 +500,17 @@ col_types_standardise <- function(spec, num_cols, col_names, col_select, name_re
     spec$cols <- spec$cols[col_names]
   }
 
-  if (inherits(col_select, "quosures") || !rlang::quo_is_null(col_select)) {
+  if (inherits(col_select, "quosures") || !quo_is_null(col_select)) {
     if (inherits(col_select, "quosures")) {
-      to_keep <- names(spec$cols) %in% tidyselect::vars_select(names(spec$cols), !!!col_select, .strict = FALSE)
+      to_keep <- names(spec$cols) %in%
+        tidyselect::vars_select(
+          names(spec$cols),
+          !!!col_select,
+          .strict = FALSE
+        )
     } else {
-      to_keep <- names(spec$cols) %in% tidyselect::vars_select(names(spec$cols), !!col_select, .strict = FALSE)
+      to_keep <- names(spec$cols) %in%
+        tidyselect::vars_select(names(spec$cols), !!col_select, .strict = FALSE)
     }
 
     spec$cols[!to_keep] <- rep(list(col_skip()), sum(!to_keep))
@@ -461,7 +535,10 @@ col_types_standardise <- function(spec, num_cols, col_names, col_select, name_re
 
 #' Guess the type of a vector
 #'
-#' @inheritParams readr::guess_parser
+#' @param x Character vector of values to parse.
+#' @inheritParams vroom
+#' @param guess_integer If `TRUE`, guess integer types for whole numbers, if
+#'   `FALSE` guess numeric type for all numbers.
 #' @examples
 #'  # Logical vectors
 #'  guess_type(c("FALSE", "TRUE", "F", "T"))
@@ -478,21 +555,38 @@ col_types_standardise <- function(spec, num_cols, col_names, col_select, name_re
 #'  guess_type(c("2010-10-10 01:02:03"))
 #'  guess_type(c("01:02:03 AM"))
 #' @export
-guess_type <- function(x, na = c("", "NA"), locale = default_locale(), guess_integer = FALSE) {
-  type <- guess_type_(x, na = na, locale = locale, guess_integer = guess_integer)
+guess_type <- function(
+  x,
+  na = c("", "NA"),
+  locale = default_locale(),
+  guess_integer = FALSE
+) {
+  type <- guess_type_(
+    x,
+    na = na,
+    locale = locale,
+    guess_integer = guess_integer
+  )
   get(paste0("col_", type), asNamespace("vroom"))()
 }
 
-guess_parser <- function(x, na = c("", "NA"), locale = default_locale(), guess_integer = FALSE) {
+guess_parser <- function(
+  x,
+  na = c("", "NA"),
+  locale = default_locale(),
+  guess_integer = FALSE
+) {
   guess_type_(x, na = na, locale = locale, guess_integer = guess_integer)
 }
 
 show_dims <- function(x) {
   cli_block(class = "vroom_dim_message", {
-    cli::cli_text("
+    cli::cli_text(
+      "
       {.strong Rows: }{.val {NROW(x)}}
       {.strong Columns: }{.val {NCOL(x)}}
-      ")
+      "
+    )
   })
 }
 
@@ -501,51 +595,89 @@ collector_value <- function(x, ...) {
 }
 
 #' @export
-collector_value.collector_character <- function(x, ...) { character() }
+collector_value.collector_character <- function(x, ...) {
+  character()
+}
 
 #' @export
-collector_value.collector_double <- function(x, ...) { numeric() }
+collector_value.collector_double <- function(x, ...) {
+  numeric()
+}
 
 #' @export
-collector_value.collector_integer <- function(x, ...) { integer() }
+collector_value.collector_integer <- function(x, ...) {
+  integer()
+}
 
 #' @export
-collector_value.collector_numeric <- function(x, ...) { numeric() }
+collector_value.collector_number <- function(x, ...) {
+  numeric()
+}
 
 #' @export
-collector_value.collector_logical <- function(x, ...) { logical() }
+collector_value.collector_logical <- function(x, ...) {
+  logical()
+}
 
 #' @export
-collector_value.collector_factor <- function(x, ...) { factor() }
+collector_value.collector_factor <- function(x, ...) {
+  factor()
+}
 
 #' @export
-collector_value.collector_datetime <- function(x, ...) { as.POSIXct(double()) }
+collector_value.collector_datetime <- function(x, ...) {
+  vctrs::new_datetime()
+}
 
 #' @export
-collector_value.collector_date <- function(x, ...) { as.Date(double()) }
+collector_value.collector_date <- function(x, ...) {
+  vctrs::new_date()
+}
 
 #' @export
-collector_value.collector_time <- function(x, ...) { hms::hms() }
+collector_value.collector_time <- function(x, ...) {
+  hms::hms()
+}
 
 #' @export
-collector_value.collector_guess <- function(x, ...) { character() }
+collector_value.collector_guess <- function(x, ...) {
+  character()
+}
 
-#' @importFrom crayon silver
-#' @importFrom glue double_quote
 #' @export
-summary.col_spec <- function(object, width = getOption("width"), locale = default_locale(), ...) {
+collector_value.collector_skip <- function(x, ...) {
+  NULL
+}
+
+#' @export
+summary.col_spec <- function(
+  object,
+  width = getOption("width"),
+  locale = default_locale(),
+  ...
+) {
   if (length(object$cols) == 0) {
     return(invisible(object))
   }
 
-  type_map <- c("collector_character" = "chr", "collector_double" = "dbl",
-    "collector_integer" = "int", "collector_number" = "num", "collector_logical" = "lgl",
-    "collector_factor" = "fct", "collector_datetime" = "dttm", "collector_date" = "date",
+  type_map <- c(
+    "collector_character" = "chr",
+    "collector_double" = "dbl",
+    "collector_integer" = "int",
+    "collector_number" = "num",
+    "collector_logical" = "lgl",
+    "collector_factor" = "fct",
+    "collector_datetime" = "dttm",
+    "collector_date" = "date",
     "collector_time" = "time",
-    "collector_guess" = "???")
+    "collector_guess" = "???"
+  )
 
   col_types <- vapply(object$cols, function(x) class(x)[[1]], character(1))
-  col_types <- droplevels(factor(type_map[col_types], levels = unname(type_map)))
+  col_types <- droplevels(factor(
+    type_map[col_types],
+    levels = unname(type_map)
+  ))
   type_counts <- table(col_types)
 
   n <- length(type_counts)
@@ -553,10 +685,18 @@ summary.col_spec <- function(object, width = getOption("width"), locale = defaul
   types <- format(vapply(names(type_counts), color_type, character(1)))
   counts <- format(glue::glue("({type_counts})"), justify = "right")
   col_width <- min(width - (crayon::col_nchar(types) + nchar(counts) + 4))
-  columns <- vapply(split(names(object$cols), col_types), function(x) glue::glue_collapse(x, ", ", width = col_width), character(1))
+  columns <- vapply(
+    split(names(object$cols), col_types),
+    function(x) glue::glue_collapse(x, ", ", width = col_width),
+    character(1)
+  )
 
   fmt_num <- function(x) {
-    prettyNum(x, big.mark = locale$grouping_mark, decimal.mark = locale$decimal_mark)
+    prettyNum(
+      x,
+      big.mark = locale$grouping_mark,
+      decimal.mark = locale$decimal_mark
+    )
   }
 
   delim <- object$delim %||% ""
@@ -566,11 +706,12 @@ summary.col_spec <- function(object, width = getOption("width"), locale = defaul
     entries = glue::glue("{format(types)} {counts}: {columns}"),
 
     '
-    {if (nzchar(delim)) paste(bold("Delimiter:"), double_quote(delim)) else ""}
+    {if (nzchar(delim)) paste(bold("Delimiter:"), glue::double_quote(delim)) else ""}
     {entries*}
 
 
-    ')
+    '
+  )
   cli_block(class = "vroom_spec_message", {
     cli::cli_h1("Column specification")
     cli::cli_verbatim(txt)
@@ -584,8 +725,12 @@ show_col_types <- function(x, locale) {
   summary(spec(x), locale = locale)
   cli_block(class = "vroom_spec_message", {
     cli::cli_verbatim("\n\n")
-    cli::cli_alert_info("Use {.fn spec} to retrieve the full column specification for this data.")
-    cli::cli_alert_info("Specify the column types or set {.arg show_col_types = FALSE} to quiet this message.")
+    cli::cli_alert_info(
+      "Use {.fn spec} to retrieve the full column specification for this data."
+    )
+    cli::cli_alert_info(
+      "Specify the column types or set {.arg show_col_types = FALSE} to quiet this message."
+    )
   })
 }
 
@@ -605,16 +750,17 @@ cli_block <- function(expr, class = NULL, type = rlang::inform) {
 }
 
 color_type <- function(type) {
-  switch(type,
+  switch(
+    type,
     chr = ,
     fct = crayon::red(type),
     lgl = crayon::yellow(type),
     dbl = ,
     int = ,
-    num = crayon::green(type),
+    num = green(type),
     date = ,
     dttm = ,
-    time = crayon::blue(type),
+    time = blue(type),
     "???" = type
   )
 }
@@ -667,15 +813,90 @@ col_guess <- function(...) {
   collector("guess", ...)
 }
 
-#' @inheritParams readr::col_factor
 #' @rdname cols
+#' @param levels Character vector of the allowed levels. When `levels = NULL`
+#'   (the default), `levels` are discovered from the unique values of the data,
+#'   in the order in which they are encountered.
+#' @param ordered Is it an ordered factor?
+#' @param include_na If `TRUE` and the data contains at least one `NA`, then
+#'   `NA` is included in the levels of the constructed factor.
 #' @export
-col_factor <- function(levels = NULL, ordered = FALSE, include_na = FALSE, ...) {
-  collector("factor", levels = levels, ordered = ordered, include_na = include_na, ...)
+col_factor <- function(
+  levels = NULL,
+  ordered = FALSE,
+  include_na = FALSE,
+  ...
+) {
+  collector(
+    "factor",
+    levels = levels,
+    ordered = ordered,
+    include_na = include_na,
+    ...
+  )
 }
 
-#' @inheritParams readr::col_datetime
 #' @rdname cols
+#' @param format A format specification. If set to "":
+#'   * `col_datetime()` expects ISO8601 datetimes. Here are some examples of
+#'     input that should just work:
+#'     "2024-01-15", "2024-01-15 14:30:00", "2024-01-15T14:30:00Z".
+#'   * `col_date()` uses the `date_format` from [locale()] (default `"%AD"`).
+#'     These inputs should just work: "2024-01-15", "01/15/2024".
+#'   * `col_time()` uses the `time_format` from [locale()] (default `"%AT"`).
+#'     These inputs should just work: "14:30:00", "2:30:00 PM".
+#'
+#'   Unlike [strptime()], the format specification must match the complete
+#'   string. For more details, see below.
+#'
+#' @details
+#' ## Date, time, and datetime formats:
+#' \pkg{vroom} uses a format specification similar to [strptime()].
+#' There are three types of element:
+#'
+#' 1. A conversion specification that is "%" followed by a letter. For example
+#'   "%Y" matches a 4 digit year, "%m", matches a 2 digit month and "%d" matches
+#'   a 2 digit day. Month and day default to `1`, (i.e. Jan 1st) if not present,
+#'   for example if only a year is given.
+#' 2. Whitespace is any sequence of zero or more whitespace characters.
+#' 3. Any other character is matched exactly.
+#'
+#' \pkg{vroom}'s datetime `col_*()` functions recognize the following
+#' specifications:
+#'
+#' * Year: "%Y" (4 digits). "%y" (2 digits); 00-69 -> 2000-2069, 70-99 ->
+#'   1970-1999.
+#' * Month: "%m" (2 digits), "%b" (abbreviated name in current locale), "%B"
+#'   (full name in current locale).
+#' * Day: "%d" (2 digits), "%e" (optional leading space), "%a" (abbreviated
+#'   name in current locale).
+#' * Hour: "%H" or "%I" or "%h", use I (and not H) with AM/PM, use h (and not H)
+#'   if your times represent durations longer than one day.
+#' * Minutes: "%M"
+#' * Seconds: "%S" (integer seconds), "%OS" (partial seconds)
+#' * Time zone: "%Z" (as name, e.g. "America/Chicago"), "%z" (as offset from
+#'   UTC, e.g. "+0800")
+#' * AM/PM indicator: "%p".
+#' * Non-digits: "%." skips one non-digit character, "%+" skips one or more
+#'   non-digit characters, "%*" skips any number of non-digits characters.
+#' * Automatic parsers: "%AD" parses with a flexible YMD parser, "%AT" parses
+#'   with a flexible HMS parser.
+#' * Shortcuts: "%D" = "%m/%d/%y", "%F" = "%Y-%m-%d", "%R" = "%H:%M", "%T" =
+#'   "%H:%M:%S", "%x" = "%y/%m/%d".
+#'
+#' ### ISO8601 support
+#'
+#' Currently, vroom does not support all of ISO8601. Missing features:
+#'
+#' * Week & weekday specifications, e.g. "2013-W05", "2013-W05-10".
+#' * Ordinal dates, e.g. "2013-095".
+#' * Using commas instead of a period for decimal separator.
+#'
+#' The parser is also a little laxer than ISO8601:
+#'
+#' * Dates and times can be separated with a space, not just T.
+#' * Mostly correct specifications like "2009-05-19 14:" and "200912-01" work.
+#'
 #' @export
 col_datetime <- function(format = "", ...) {
   collector("datetime", format = format, ...)
