@@ -2,6 +2,7 @@
 
 #include <cpp11/doubles.hpp>
 
+#include "r_utils.h"
 #include "vroom_dttm.h"
 
 using namespace vroom;
@@ -14,9 +15,6 @@ double parse_date(
 
 cpp11::doubles read_date(vroom_vec_info* info);
 
-#ifdef HAS_ALTREP
-/* no support for altrep before 3.5 */
-
 class vroom_date : public vroom_dttm {
 
 public:
@@ -47,7 +45,7 @@ public:
   static Rboolean
   Inspect(SEXP x, int, int, int, void (*)(SEXP, int, int, int)) {
     Rprintf(
-        "vroom_date (len=%d, materialized=%s)\n",
+        "vroom_date (len=%" R_PRIdXLEN_T ", materialized=%s)\n",
         Length(x),
         R_altrep_data2(x) != R_NilValue ? "T" : "F");
     return TRUE;
@@ -67,7 +65,7 @@ public:
                        : std::string("date like ") + info->info->format;
 
     double out = parse_value<double>(
-        info->info->column->begin() + i,
+        i,
         info->info->column,
         [&](const char* begin, const char* end) -> double {
           return parse_date(begin, end, *info->parser, info->info->format);
@@ -101,7 +99,7 @@ public:
   }
 
   static void* Dataptr(SEXP vec, Rboolean) {
-    return STDVEC_DATAPTR(Materialize(vec));
+    return DATAPTR_RW(Materialize(vec));
   }
 
   // -------- initialize the altrep class with the methods above
@@ -121,7 +119,6 @@ public:
     R_set_altreal_Elt_method(class_t, date_Elt);
   }
 };
-#endif
 
 // Called the package is loaded
 [[cpp11::init]] void init_vroom_date(DllInfo* dll);
