@@ -3,6 +3,7 @@
 #include <cpp11/strings.hpp>
 
 #include "altrep.h"
+#include "r_utils.h"
 #include "vroom.h"
 #include "vroom_vec.h"
 
@@ -68,8 +69,6 @@ int parse_factor(
   }
 }
 
-#ifdef HAS_ALTREP
-
 struct vroom_factor_info {
   vroom_vec_info* info;
   std::unordered_map<SEXP, size_t> levels;
@@ -122,7 +121,7 @@ public:
   static Rboolean
   Inspect(SEXP x, int, int, int, void (*)(SEXP, int, int, int)) {
     Rprintf(
-        "vroom_factor (len=%d, materialized=%s)\n",
+        "vroom_factor (len=%" R_PRIdXLEN_T ", materialized=%s)\n",
         Length(x),
         R_altrep_data2(x) != R_NilValue ? "T" : "F");
     return TRUE;
@@ -214,7 +213,7 @@ public:
   }
 
   static void* Dataptr(SEXP vec, Rboolean) {
-    return STDVEC_DATAPTR(Materialize(vec));
+    return DATAPTR_RW(Materialize(vec));
   }
 
   static SEXP Extract_subset(SEXP x, SEXP indx, SEXP) {
@@ -270,7 +269,6 @@ public:
     R_set_altinteger_Elt_method(class_t, factor_Elt);
   }
 };
-#endif
 
 // Called the package is loaded
 [[cpp11::init]] void init_vroom_fct(DllInfo* dll);
